@@ -33,7 +33,7 @@ class Lease(base.APIDictWrapper):
                 ) = ('IN_PROGRESS', 'FAILED', 'COMPLETE')
 
     _attrs = ['id', 'name', 'start_date', 'end_date', 'user_id', 'project_id',
-              'before_end_date', 'action', 'status', 'status_reason']
+              'before_end_date', 'status', 'degraded']
 
     def __init__(self, apiresource):
         super(Lease, self).__init__(apiresource)
@@ -45,7 +45,7 @@ class Host(base.APIDictWrapper):
     _attrs = ['id', 'hypervisor_hostname', 'hypervisor_type',
               'hypervisor_version', 'vcpus', 'cpu_info', 'memory_mb',
               'local_gb', 'status', 'created_at', 'updated_at',
-              'service_name', 'trust_id']
+              'service_name', 'trust_id', 'reservable']
 
     def __init__(self, apiresource):
         super(Host, self).__init__(apiresource)
