@@ -10,6 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from django import http
 from openstack_dashboard.test import helpers
 
 from blazar_dashboard.test.test_data import utils
@@ -29,3 +30,18 @@ class BaseAdminViewTests(helpers.BaseAdminViewTests):
     def _setup_test_data(self):
         super(BaseAdminViewTests, self)._setup_test_data()
         utils.load_test_data(self)
+
+
+class IsA(object):
+    """Class to compare param is a specified class."""
+    def __init__(self, cls):
+        self.cls = cls
+
+    def __eq__(self, other):
+        return isinstance(other, self.cls)
+
+
+class IsHttpRequest(IsA):
+    """Class to compare param is django.http.HttpRequest."""
+    def __init__(self):
+        super(IsHttpRequest, self).__init__(http.HttpRequest)
